@@ -14,12 +14,15 @@
 #' @inheritParams argument_convention
 #' @param category (`list`)\cr with different marked category names for single
 #'   and last or replicated.
+#' @param .stats (`character`)\cr statistics to select for the table. Run `get_stats("abnormal_by_marked")`
+#'   to see available statistics for this function.
 #'
 #' @note `Single, not last` and `Last or replicated` levels are mutually exclusive. If a patient has
 #'   abnormalities that meet both the `Single, not last` and `Last or replicated` criteria, then the
 #'   patient will be counted only under the `Last or replicated` category.
 #'
 #' @name abnormal_by_marked
+#' @order 1
 NULL
 
 #' @describeIn abnormal_by_marked Statistics function for patients with marked lab abnormalities.
@@ -28,46 +31,6 @@ NULL
 #' * `s_count_abnormal_by_marked()` returns statistic `count_fraction` with `Single, not last`,
 #'   `Last or replicated`, and `Any` results.
 #'
-#' @examples
-#' library(dplyr)
-#'
-#' df <- data.frame(
-#'   USUBJID = as.character(c(rep(1, 5), rep(2, 5), rep(1, 5), rep(2, 5))),
-#'   ARMCD = factor(c(rep("ARM A", 5), rep("ARM B", 5), rep("ARM A", 5), rep("ARM B", 5))),
-#'   ANRIND = factor(c(
-#'     "NORMAL", "HIGH", "HIGH", "HIGH HIGH", "HIGH",
-#'     "HIGH", "HIGH", "HIGH HIGH", "NORMAL", "HIGH HIGH", "NORMAL", "LOW", "LOW", "LOW LOW", "LOW",
-#'     "LOW", "LOW", "LOW LOW", "NORMAL", "LOW LOW"
-#'   )),
-#'   ONTRTFL = rep(c("", "Y", "Y", "Y", "Y", "Y", "Y", "Y", "Y", "Y"), 2),
-#'   PARAMCD = factor(c(rep("CRP", 10), rep("ALT", 10))),
-#'   AVALCAT1 = factor(rep(c("", "", "", "SINGLE", "REPLICATED", "", "", "LAST", "", "SINGLE"), 2)),
-#'   stringsAsFactors = FALSE
-#' )
-#'
-#' df <- df %>%
-#'   mutate(abn_dir = factor(
-#'     case_when(
-#'       ANRIND == "LOW LOW" ~ "Low",
-#'       ANRIND == "HIGH HIGH" ~ "High",
-#'       TRUE ~ ""
-#'     ),
-#'     levels = c("Low", "High")
-#'   ))
-#'
-#' # Select only post-baseline records.
-#' df <- df %>% filter(ONTRTFL == "Y")
-#' df_crp <- df %>%
-#'   filter(PARAMCD == "CRP") %>%
-#'   droplevels()
-#' full_parent_df <- list(df_crp, "not_needed")
-#' cur_col_subset <- list(rep(TRUE, nrow(df_crp)), "not_needed")
-#' spl_context <- data.frame(
-#'   split = c("PARAMCD", "GRADE_DIR"),
-#'   full_parent_df = I(full_parent_df),
-#'   cur_col_subset = I(cur_col_subset)
-#' )
-#'
 #' @keywords internal
 s_count_abnormal_by_marked <- function(df,
                                        .var = "AVALCAT1",
@@ -128,7 +91,6 @@ s_count_abnormal_by_marked <- function(df,
 #' @return
 #' * `a_count_abnormal_by_marked()` returns the corresponding list with formatted [rtables::CellValue()].
 #'
-#'
 #' @keywords internal
 a_count_abnormal_by_marked <- make_afun(
   s_count_abnormal_by_marked,
@@ -144,6 +106,45 @@ a_count_abnormal_by_marked <- make_afun(
 #'   the statistics from `s_count_abnormal_by_marked()` to the table layout.
 #'
 #' @examples
+#' library(dplyr)
+#'
+#' df <- data.frame(
+#'   USUBJID = as.character(c(rep(1, 5), rep(2, 5), rep(1, 5), rep(2, 5))),
+#'   ARMCD = factor(c(rep("ARM A", 5), rep("ARM B", 5), rep("ARM A", 5), rep("ARM B", 5))),
+#'   ANRIND = factor(c(
+#'     "NORMAL", "HIGH", "HIGH", "HIGH HIGH", "HIGH",
+#'     "HIGH", "HIGH", "HIGH HIGH", "NORMAL", "HIGH HIGH", "NORMAL", "LOW", "LOW", "LOW LOW", "LOW",
+#'     "LOW", "LOW", "LOW LOW", "NORMAL", "LOW LOW"
+#'   )),
+#'   ONTRTFL = rep(c("", "Y", "Y", "Y", "Y", "Y", "Y", "Y", "Y", "Y"), 2),
+#'   PARAMCD = factor(c(rep("CRP", 10), rep("ALT", 10))),
+#'   AVALCAT1 = factor(rep(c("", "", "", "SINGLE", "REPLICATED", "", "", "LAST", "", "SINGLE"), 2)),
+#'   stringsAsFactors = FALSE
+#' )
+#'
+#' df <- df %>%
+#'   mutate(abn_dir = factor(
+#'     case_when(
+#'       ANRIND == "LOW LOW" ~ "Low",
+#'       ANRIND == "HIGH HIGH" ~ "High",
+#'       TRUE ~ ""
+#'     ),
+#'     levels = c("Low", "High")
+#'   ))
+#'
+#' # Select only post-baseline records.
+#' df <- df %>% filter(ONTRTFL == "Y")
+#' df_crp <- df %>%
+#'   filter(PARAMCD == "CRP") %>%
+#'   droplevels()
+#' full_parent_df <- list(df_crp, "not_needed")
+#' cur_col_subset <- list(rep(TRUE, nrow(df_crp)), "not_needed")
+#' spl_context <- data.frame(
+#'   split = c("PARAMCD", "GRADE_DIR"),
+#'   full_parent_df = I(full_parent_df),
+#'   cur_col_subset = I(cur_col_subset)
+#' )
+#'
 #' map <- unique(
 #'   df[df$abn_dir %in% c("Low", "High") & df$AVALCAT1 != "", c("PARAMCD", "abn_dir")]
 #' ) %>%
@@ -194,8 +195,12 @@ a_count_abnormal_by_marked <- make_afun(
 #'   build_table(df = df)
 #'
 #' @export
+#' @order 2
 count_abnormal_by_marked <- function(lyt,
                                      var,
+                                     category = list(single = "SINGLE", last_replicated = c("LAST", "REPLICATED")),
+                                     variables = list(id = "USUBJID", param = "PARAM", direction = "abn_dir"),
+                                     na_str = default_na_str(),
                                      nested = TRUE,
                                      ...,
                                      .stats = NULL,
@@ -204,6 +209,8 @@ count_abnormal_by_marked <- function(lyt,
                                      .indent_mods = NULL) {
   checkmate::assert_string(var)
 
+  extra_args <- list(category = category, variables = variables, ...)
+
   afun <- make_afun(
     a_count_abnormal_by_marked,
     .stats = .stats,
@@ -217,9 +224,10 @@ count_abnormal_by_marked <- function(lyt,
     lyt = lyt,
     vars = var,
     afun = afun,
+    na_str = na_str,
     nested = nested,
     show_labels = "hidden",
-    extra_args = c(list(...))
+    extra_args = extra_args
   )
   lyt
 }
