@@ -5,10 +5,16 @@
 #' The primary analysis variable `.var` denotes the unique patient identifier.
 #'
 #' @inheritParams argument_convention
+#' @param flag_variables (`character`)\cr a character vector specifying the names of `logical`
+#'   variables from analysis dataset used for counting the number of unique identifiers.
+#' @param flag_labels (`character`)\cr vector of labels to use for flag variables.
+#' @param .stats (`character`)\cr statistics to select for the table. Run `get_stats("count_patients_with_flags")`
+#'   to see available statistics for this function.
 #'
 #' @seealso [count_patients_with_event]
 #'
 #' @name count_patients_with_flags
+#' @order 1
 NULL
 
 #' @describeIn count_patients_with_flags Statistics function which counts the number of patients for which
@@ -16,9 +22,6 @@ NULL
 #'
 #' @inheritParams analyze_variables
 #' @param .var (`character`)\cr name of the column that contains the unique identifier.
-#' @param flag_variables (`character`)\cr a character vector specifying the names of `logical`
-#'   variables from analysis dataset used for counting the number of unique identifiers.
-#' @param flag_labels (`character`)\cr vector of labels to use for flag variables.
 #'
 #' @note If `flag_labels` is not specified, variables labels will be extracted from `df`. If variables are not
 #'   labeled, variable names will be used instead. Alternatively, a named `vector` can be supplied to
@@ -30,26 +33,8 @@ NULL
 #'   flag as a list of statistics `n`, `count`, `count_fraction`, and `n_blq`, with one element per flag.
 #'
 #' @examples
-#' library(dplyr)
-#'
 #' # `s_count_patients_with_flags()`
 #'
-#' # Add labelled flag variables to analysis dataset.
-#' adae <- tern_ex_adae %>%
-#'   mutate(
-#'     fl1 = TRUE,
-#'     fl2 = TRTEMFL == "Y",
-#'     fl3 = TRTEMFL == "Y" & AEOUT == "FATAL",
-#'     fl4 = TRTEMFL == "Y" & AEOUT == "FATAL" & AEREL == "Y"
-#'   )
-#' labels <- c(
-#'   "fl1" = "Total AEs",
-#'   "fl2" = "Total number of patients with at least one adverse event",
-#'   "fl3" = "Total number of patients with fatal AEs",
-#'   "fl4" = "Total number of patients with related fatal AEs"
-#' )
-#' formatters::var_labels(adae)[names(labels)] <- labels
-#'
 #' s_count_patients_with_flags(
 #'   adae,
 #'   "SUBJID",
@@ -140,6 +125,20 @@ a_count_patients_with_flags <- make_afun(
 #'   the statistics from `s_count_patients_with_flags()` to the table layout.
 #'
 #' @examples
+#' library(dplyr)
+#'
+#' # Add labelled flag variables to analysis dataset.
+#' adae <- tern_ex_adae %>%
+#'   mutate(
+#'     fl1 = TRUE %>% with_label("Total AEs"),
+#'     fl2 = (TRTEMFL == "Y") %>%
+#'       with_label("Total number of patients with at least one adverse event"),
+#'     fl3 = (TRTEMFL == "Y" & AEOUT == "FATAL") %>%
+#'       with_label("Total number of patients with fatal AEs"),
+#'     fl4 = (TRTEMFL == "Y" & AEOUT == "FATAL" & AEREL == "Y") %>%
+#'       with_label("Total number of patients with related fatal AEs")
+#'   )
+#'
 #' # `count_patients_with_flags()`
 #'
 #' lyt2 <- basic_table() %>%
@@ -150,14 +149,19 @@ a_count_patients_with_flags <- make_afun(
 #'     flag_variables = c("fl1", "fl2", "fl3", "fl4"),
 #'     denom = "N_col"
 #'   )
+#'
 #' build_table(lyt2, adae, alt_counts_df = tern_ex_adsl)
 #'
 #' @export
+#' @order 2
 count_patients_with_flags <- function(lyt,
                                       var,
+                                      flag_variables,
+                                      flag_labels = NULL,
                                       var_labels = var,
                                       show_labels = "hidden",
                                       riskdiff = FALSE,
+                                      na_str = default_na_str(),
                                       nested = TRUE,
                                       ...,
                                       table_names = paste0("tbl_flags_", var),
@@ -166,6 +170,8 @@ count_patients_with_flags <- function(lyt,
                                       .indent_mods = NULL) {
   checkmate::assert_flag(riskdiff)
 
+  s_args <- list(flag_variables = flag_variables, flag_labels = flag_labels, ...)
+
   afun <- make_afun(
     a_count_patients_with_flags,
     .stats = .stats,
@@ -175,13 +181,13 @@ count_patients_with_flags <- function(lyt,
   )
 
   extra_args <- if (isFALSE(riskdiff)) {
-    list(...)
+    s_args
   } else {
     list(
       afun = list("s_count_patients_with_flags" = afun),
       .stats = .stats,
       .indent_mods = .indent_mods,
-      s_args = list(...)
+      s_args = s_args
     )
   }
 
@@ -192,6 +198,7 @@ count_patients_with_flags <- function(lyt,
     show_labels = show_labels,
     afun = ifelse(isFALSE(riskdiff), afun, afun_riskdiff),
     table_names = table_names,
+    na_str = na_str,
     nested = nested,
     extra_args = extra_args
   )
