@@ -132,8 +132,8 @@ decorate_grob <- function(grob,
                           titles,
                           footnotes,
                           page = "",
-                          width_titles = grid::unit(1, "npc") - grid::stringWidth(page),
-                          width_footnotes = grid::unit(1, "npc") - grid::stringWidth(page),
+                          width_titles = grid::unit(1, "npc") - grid::unit(1.5, "cm"),
+                          width_footnotes = grid::unit(1, "npc") - grid::unit(1.5, "cm"),
                           border = TRUE,
                           margins = grid::unit(c(1, 0, 1, 0), "lines"),
                           padding = grid::unit(rep(1, 4), "lines"),
@@ -161,6 +161,14 @@ decorate_grob <- function(grob,
     gp = gp_footnotes
   )
 
+  pg_footnote <- grid::textGrob(
+    paste("\n", page),
+    x = 1, y = 0,
+    just = c("right", "bottom"),
+    vp = grid::viewport(layout.pos.row = 4, layout.pos.col = 1),
+    gp = gp_footnotes
+  )
+
   grid::gTree(
     grob = grob,
     titles = titles,
@@ -194,13 +202,7 @@ decorate_grob <- function(grob,
             )
           ),
           st_footnotes,
-          grid::textGrob(
-            page,
-            x = 1, y = 0,
-            just = c("right", "bottom"),
-            vp = grid::viewport(layout.pos.row = 3, layout.pos.col = 1),
-            gp = gp_footnotes
-          )
+          pg_footnote
         ),
         childrenvp = NULL,
         name = "titles_grob_footnotes",
@@ -208,11 +210,12 @@ decorate_grob <- function(grob,
           grid::plotViewport(margins = outer_margins),
           grid::viewport(
             layout = grid::grid.layout(
-              nrow = 3, ncol = 1,
+              nrow = 4, ncol = 1,
               heights = grid::unit.c(
                 grid::grobHeight(st_titles),
                 grid::unit(1, "null"),
-                grid::grobHeight(st_footnotes)
+                grid::grobHeight(st_footnotes),
+                grid::grobHeight(pg_footnote)
               )
             )
           )
@@ -325,10 +328,14 @@ split_text_grob <- function(text,
   if (grid::unitType(y) %in% c("sum", "min", "max")) y <- grid::convertUnit(y, default.units)
   if (grid::unitType(width) %in% c("sum", "min", "max")) width <- grid::convertUnit(width, default.units)
 
+  if (length(gp) > 0) { # account for effect of gp on text width
+    width <- width * grid::convertWidth(grid::grobWidth(grid::textGrob(text)), "npc", valueOnly = TRUE) /
+      grid::convertWidth(grid::grobWidth(grid::textGrob(text, gp = gp)), "npc", valueOnly = TRUE)
+  }
+
   ## if it is a fixed unit then we do not need to recalculate when viewport resized
-  if (!inherits(width, "unit.arithmetic") &&
-    !is.null(attr(width, "unit")) &&
-    attr(width, "unit") %in% c("cm", "inches", "mm", "points", "picas", "bigpts", "dida", "cicero", "scaledpts")) {
+  if (!inherits(width, "unit.arithmetic") && !is.null(attr(width, "unit")) &&
+    attr(width, "unit") %in% c("cm", "inches", "mm", "points", "picas", "bigpts", "dida", "cicero", "scaledpts")) { # nolint
     attr(text, "fixed_text") <- paste(vapply(text, split_string, character(1), width = width), collapse = "\n")
   }
 
