@@ -33,12 +33,14 @@ h_recycle <- function(...) {
 #'   * `upr.ci`: estimate of upper end of the confidence interval.
 #'
 #' @keywords internal
-desctools_binom <- function(x1, n1, x2, n2, conf.level = 0.95, sides = c( # nolint
-                              "two.sided",
-                              "left", "right"
-                            ), method = c(
-                              "ac", "wald", "waldcc", "score",
-                              "scorecc", "mn", "mee", "blj", "ha", "hal", "jp"
+desctools_binom <- function(x1,
+                            n1,
+                            x2,
+                            n2,
+                            conf.level = 0.95, # nolint
+                            sides = c("two.sided", "left", "right"),
+                            method = c(
+                              "ac", "wald", "waldcc", "score", "scorecc", "mn", "mee", "blj", "ha", "hal", "jp"
                             )) {
   if (missing(sides)) {
     sides <- match.arg(sides)
@@ -46,8 +48,7 @@ desctools_binom <- function(x1, n1, x2, n2, conf.level = 0.95, sides = c( # noli
   if (missing(method)) {
     method <- match.arg(method)
   }
-  iBinomDiffCI <- function(x1, n1, x2, n2, conf.level, sides, # nolint
-                           method) {
+  iBinomDiffCI <- function(x1, n1, x2, n2, conf.level, sides, method) { # nolint
     if (sides != "two.sided") {
       conf.level <- 1 - 2 * (1 - conf.level) # nolint
     }
@@ -100,10 +101,8 @@ desctools_binom <- function(x1, n1, x2, n2, conf.level = 0.95, sides = c( # noli
         u1 <- w1[3]
         l2 <- w2[2]
         u2 <- w2[3]
-        ci_lwr <- est - kappa * sqrt(l1 * (1 - l1) / n1 +
-          u2 * (1 - u2) / n2)
-        ci_upr <- est + kappa * sqrt(u1 * (1 - u1) / n1 +
-          l2 * (1 - l2) / n2)
+        ci_lwr <- est - kappa * sqrt(l1 * (1 - l1) / n1 + u2 * (1 - u2) / n2)
+        ci_upr <- est + kappa * sqrt(u1 * (1 - u1) / n1 + l2 * (1 - l2) / n2)
       },
       scorecc = {
         w1 <- desctools_binomci(
@@ -118,10 +117,8 @@ desctools_binom <- function(x1, n1, x2, n2, conf.level = 0.95, sides = c( # noli
         u1 <- w1[3]
         l2 <- w2[2]
         u2 <- w2[3]
-        ci_lwr <- max(-1, est - sqrt((p1_hat - l1)^2 +
-          (u2 - p2_hat)^2))
-        ci_upr <- min(1, est + sqrt((u1 - p1_hat)^2 + (p2_hat -
-          l2)^2))
+        ci_lwr <- max(-1, est - sqrt((p1_hat - l1)^2 + (u2 - p2_hat)^2))
+        ci_upr <- min(1, est + sqrt((u1 - p1_hat)^2 + (p2_hat - l2)^2))
       },
       mee = {
         .score <- function(p1, n1, p2, n2, dif) {
@@ -134,8 +131,7 @@ desctools_binom <- function(x1, n1, x2, n2, conf.level = 0.95, sides = c( # noli
             t <- n2 / n1
             a <- 1 + t
             b <- -(1 + t + p1 + t * p2 + dif * (t + 2))
-            c <- dif * dif + dif * (2 * p1 + t + 1) + p1 +
-              t * p2
+            c <- dif * dif + dif * (2 * p1 + t + 1) + p1 + t * p2
             d <- -p1 * dif * (1 + dif)
             v <- (b / a / 3)^3 - b * c / (6 * a * a) + d / a / 2
             if (abs(v) < .Machine$double.eps) v <- 0
@@ -150,35 +146,28 @@ desctools_binom <- function(x1, n1, x2, n2, conf.level = 0.95, sides = c( # noli
           return(sqrt(res))
         }
         pval <- function(delta) {
-          z <- (est - delta) / .score(
-            p1_hat, n1, p2_hat,
-            n2, delta
-          )
+          z <- (est - delta) / .score(p1_hat, n1, p2_hat, n2, delta)
           2 * min(stats::pnorm(z), 1 - stats::pnorm(z))
         }
         ci_lwr <- max(-1, stats::uniroot(function(delta) {
-          pval(delta) -
-            alpha
+          pval(delta) - alpha
         }, interval = c(-1 + 1e-06, est - 1e-06))$root)
         ci_upr <- min(1, stats::uniroot(function(delta) {
-          pval(delta) -
-            alpha
+          pval(delta) - alpha
         }, interval = c(est + 1e-06, 1 - 1e-06))$root)
       },
       blj = {
         p1_dash <- (x1 + 0.5) / (n1 + 1)
         p2_dash <- (x2 + 0.5) / (n2 + 1)
-        vd <- p1_dash * (1 - p1_dash) / n1 + p2_dash * (1 -
-          p2_dash) / n2
+        vd <- p1_dash * (1 - p1_dash) / n1 + p2_dash * (1 - p2_dash) / n2
         term2 <- kappa * sqrt(vd)
         est_dash <- p1_dash - p2_dash
         ci_lwr <- max(-1, est_dash - term2)
         ci_upr <- min(1, est_dash + term2)
       },
       ha = {
-        term2 <- 1 / (2 * min(n1, n2)) + kappa * sqrt(p1_hat *
-          (1 - p1_hat) / (n1 - 1) + p2_hat * (1 - p2_hat) / (n2 -
-            1))
+        term2 <- 1 /
+          (2 * min(n1, n2)) + kappa * sqrt(p1_hat * (1 - p1_hat) / (n1 - 1) + p2_hat * (1 - p2_hat) / (n2 - 1))
         ci_lwr <- max(-1, est - term2)
         ci_upr <- min(1, est + term2)
       },
@@ -199,8 +188,7 @@ desctools_binom <- function(x1, n1, x2, n2, conf.level = 0.95, sides = c( # noli
             if ((dp < 1e-07) || (abs(z - score) < 1e-06)) {
               (break)()
             } else {
-              i <- i +
-                1
+              i <- i + 1
             }
           }
           return(y)
@@ -213,8 +201,7 @@ desctools_binom <- function(x1, n1, x2, n2, conf.level = 0.95, sides = c( # noli
             t <- n2 / n1
             a <- 1 + t
             b <- -(1 + t + p1 + t * p2 + dif * (t + 2))
-            c <- dif * dif + dif * (2 * p1 + t + 1) + p1 +
-              t * p2
+            c <- dif * dif + dif * (2 * p1 + t + 1) + p1 + t * p2
             d <- -p1 * dif * (1 + dif)
             v <- (b / a / 3)^3 - b * c / (6 * a * a) + d / a / 2
             s <- sqrt((b / a / 3)^2 - c / a / 3)
@@ -223,8 +210,7 @@ desctools_binom <- function(x1, n1, x2, n2, conf.level = 0.95, sides = c( # noli
             p1d <- 2 * u * cos(w) - b / a / 3
             p2d <- p1d - dif
             n <- n1 + n2
-            var <- (p1d * (1 - p1d) / n1 + p2d * (1 - p2d) / n2) *
-              n / (n - 1)
+            var <- (p1d * (1 - p1d) / n1 + p2d * (1 - p2d) / n2) * n / (n - 1)
             res <- diff^2 / var
           }
           return(res)
@@ -250,28 +236,21 @@ desctools_binom <- function(x1, n1, x2, n2, conf.level = 0.95, sides = c( # noli
         u <- (1 / n1 + 1 / n2) / 4
         v <- (1 / n1 - 1 / n2) / 4
         z <- kappa
-        theta <- ((p1_hat - p2_hat) + z^2 * v * (1 - 2 *
-          psi)) / (1 + z^2 * u)
-        w <- z / (1 + z^2 * u) * sqrt(u * (4 * psi * (1 - psi) -
-          (p1_hat - p2_hat)^2) + 2 * v * (1 - 2 * psi) *
-          (p1_hat - p2_hat) + 4 * z^2 * u^2 * (1 - psi) *
-          psi + z^2 * v^2 * (1 - 2 * psi)^2)
+        theta <- ((p1_hat - p2_hat) + z^2 * v * (1 - 2 * psi)) / (1 + z^2 * u)
+        w <- z / (1 + z^2 * u) * sqrt(u * (4 * psi * (1 - psi) - (p1_hat - p2_hat)^2) + 2 * v * (1 - 2 * psi) *
+          (p1_hat - p2_hat) + 4 * z^2 * u^2 * (1 - psi) * psi + z^2 * v^2 * (1 - 2 * psi)^2) # nolint
         c(theta + w, theta - w)
         ci_lwr <- max(-1, theta - w)
         ci_upr <- min(1, theta + w)
       },
       jp = {
-        psi <- 0.5 * ((x1 + 0.5) / (n1 + 1) + (x2 + 0.5) / (n2 +
-          1))
+        psi <- 0.5 * ((x1 + 0.5) / (n1 + 1) + (x2 + 0.5) / (n2 + 1))
         u <- (1 / n1 + 1 / n2) / 4
         v <- (1 / n1 - 1 / n2) / 4
         z <- kappa
-        theta <- ((p1_hat - p2_hat) + z^2 * v * (1 - 2 *
-          psi)) / (1 + z^2 * u)
-        w <- z / (1 + z^2 * u) * sqrt(u * (4 * psi * (1 - psi) -
-          (p1_hat - p2_hat)^2) + 2 * v * (1 - 2 * psi) *
-          (p1_hat - p2_hat) + 4 * z^2 * u^2 * (1 - psi) *
-          psi + z^2 * v^2 * (1 - 2 * psi)^2)
+        theta <- ((p1_hat - p2_hat) + z^2 * v * (1 - 2 * psi)) / (1 + z^2 * u)
+        w <- z / (1 + z^2 * u) * sqrt(u * (4 * psi * (1 - psi) - (p1_hat - p2_hat)^2) + 2 * v * (1 - 2 * psi) *
+          (p1_hat - p2_hat) + 4 * z^2 * u^2 * (1 - psi) * psi + z^2 * v^2 * (1 - 2 * psi)^2) # nolint
         c(theta + w, theta - w)
         ci_lwr <- max(-1, theta - w)
         ci_upr <- min(1, theta + w)
@@ -361,15 +340,14 @@ desctools_binomci <- function(x,
   if (missing(sides)) {
     sides <- "two.sided"
   }
-  iBinomCI <- function(x, n, conf.level = 0.95, sides = c( # nolint
-                         "two.sided",
-                         "left", "right"
-                       ), method = c(
+  iBinomCI <- function(x, n, conf.level = 0.95, sides = c("two.sided", "left", "right"), # nolint
+                       method = c(
                          "wilson", "wilsoncc", "wald",
                          "waldcc", "agresti-coull", "jeffreys", "modified wilson",
                          "modified jeffreys", "clopper-pearson", "arcsine", "logit",
                          "witting", "pratt", "midp", "lik", "blaker"
-                       ), rand = 123,
+                       ),
+                       rand = 123,
                        tol = 1e-05) {
     if (length(x) != 1) {
       stop("'x' has to be of length 1 (number of successes)")
@@ -415,18 +393,17 @@ desctools_binomci <- function(x,
     },
     wilson = {
       term1 <- (x + kappa^2 / 2) / (n + kappa^2)
-      term2 <- kappa * sqrt(n) / (n + kappa^2) * sqrt(p_hat *
-        q_hat + kappa^2 / (4 * n))
+      term2 <- kappa * sqrt(n) / (n + kappa^2) * sqrt(p_hat * q_hat + kappa^2 / (4 * n))
       ci_lwr <- max(0, term1 - term2)
       ci_upr <- min(1, term1 + term2)
     },
     wilsoncc = {
-      lci <- (2 * x + kappa^2 - 1 - kappa * sqrt(kappa^2 -
-        2 - 1 / n + 4 * p_hat * (n * q_hat + 1))) / (2 *
-        (n + kappa^2))
-      uci <- (2 * x + kappa^2 + 1 + kappa * sqrt(kappa^2 +
-        2 - 1 / n + 4 * p_hat * (n * q_hat - 1))) / (2 *
-        (n + kappa^2))
+      lci <- (
+        2 * x + kappa^2 - 1 - kappa * sqrt(kappa^2 - 2 - 1 / n + 4 * p_hat * (n * q_hat + 1))
+      ) / (2 * (n + kappa^2))
+      uci <- (
+        2 * x + kappa^2 + 1 + kappa * sqrt(kappa^2 + 2 - 1 / n + 4 * p_hat * (n * q_hat - 1))
+      ) / (2 * (n + kappa^2))
       ci_lwr <- max(0, ifelse(p_hat == 0, 0, lci))
       ci_upr <- min(1, ifelse(p_hat == 1, 1, uci))
     },
@@ -452,30 +429,24 @@ desctools_binomci <- function(x,
       if (x == n) {
         ci_upr <- 1
       } else {
-        ci_upr <- stats::qbeta(1 -
-          alpha / 2, x + 0.5, n - x + 0.5)
+        ci_upr <- stats::qbeta(1 - alpha / 2, x + 0.5, n - x + 0.5)
       }
     },
     `modified wilson` = {
       term1 <- (x + kappa^2 / 2) / (n + kappa^2)
-      term2 <- kappa * sqrt(n) / (n + kappa^2) * sqrt(p_hat *
-        q_hat + kappa^2 / (4 * n))
-      if ((n <= 50 & x %in% c(1, 2)) | (n >= 51 & x %in%
-        c(1:3))) {
-        ci_lwr <- 0.5 * stats::qchisq(alpha, 2 *
-          x) / n
+      term2 <- kappa * sqrt(n) / (n + kappa^2) * sqrt(p_hat * q_hat + kappa^2 / (4 * n))
+      if ((n <= 50 & x %in% c(1, 2)) | (n >= 51 & x %in% c(1:3))) {
+        ci_lwr <- 0.5 * stats::qchisq(alpha, 2 * x) / n
       } else {
         ci_lwr <- max(0, term1 - term2)
       }
-      if ((n <= 50 & x %in% c(n - 1, n - 2)) | (n >= 51 &
-        x %in% c(n - (1:3)))) {
+      if ((n <= 50 & x %in% c(n - 1, n - 2)) | (n >= 51 & x %in% c(n - (1:3)))) {
         ci_upr <- 1 - 0.5 * stats::qchisq(
           alpha,
           2 * (n - x)
         ) / n
       } else {
-        ci_upr <- min(1, term1 +
-          term2)
+        ci_upr <- min(1, term1 + term2)
       }
     },
     `modified jeffreys` = {
@@ -497,8 +468,7 @@ desctools_binomci <- function(x,
         if (x >= n - 1) {
           ci_upr <- 1
         } else {
-          ci_upr <- stats::qbeta(1 -
-            alpha / 2, x + 0.5, n - x + 0.5)
+          ci_upr <- stats::qbeta(1 - alpha / 2, x + 0.5, n - x + 0.5)
         }
       }
     },
@@ -578,8 +548,7 @@ desctools_binomci <- function(x,
           (1 - conf.level) / 2
       }
       f_up <- function(pi, x, n) {
-        1 / 2 * stats::dbinom(x, size = n, prob = pi) + stats::pbinom(x -
-          1, size = n, prob = pi) - (1 - conf.level) / 2
+        1 / 2 * stats::dbinom(x, size = n, prob = pi) + stats::pbinom(x - 1, size = n, prob = pi) - (1 - conf.level) / 2
       }
       ci_lwr <- 0
       ci_upr <- 1
@@ -611,8 +580,7 @@ desctools_binomci <- function(x,
           wt, mu,
           log = TRUE
         ))
-        res <- ifelse(abs(y - mu) < tol, 0, sign(y -
-          mu) * sqrt(-2 * (ll_y - ll_mu)))
+        res <- ifelse(abs(y - mu) < tol, 0, sign(y - mu) * sqrt(-2 * (ll_y - ll_mu)))
         return(res - bound)
       }
       if (x != 0 && tol < p_hat) {
@@ -621,8 +589,7 @@ desctools_binomci <- function(x,
           tol
         ) <= 0) {
           stats::uniroot(
-            f = BinDev, interval = c(tol, if (p_hat <
-              tol || p_hat == 1) {
+            f = BinDev, interval = c(tol, if (p_hat < tol || p_hat == 1) {
               1 - tol
             } else {
               p_hat
@@ -632,12 +599,10 @@ desctools_binomci <- function(x,
         }
       }
       if (x != n && p_hat < (1 - tol)) {
-        ci_upr <- if (BinDev(y = 1 - tol, x = x, mu = ifelse(p_hat >
-          1 - tol, tol, p_hat), wt = n, bound = z, tol = tol) <
-          0) {
+        ci_upr <- if (
+          BinDev(y = 1 - tol, x = x, mu = ifelse(p_hat > 1 - tol, tol, p_hat), wt = n, bound = z, tol = tol) < 0) { # nolint
           ci_lwr <- if (BinDev(
-            tol, x, if (p_hat <
-              tol || p_hat == 1) {
+            tol, x, if (p_hat < tol || p_hat == 1) {
               1 - tol
             } else {
               p_hat
@@ -651,8 +616,7 @@ desctools_binomci <- function(x,
           }
         } else {
           stats::uniroot(
-            f = BinDev, interval = c(if (p_hat >
-              1 - tol) {
+            f = BinDev, interval = c(if (p_hat > 1 - tol) {
               tol
             } else {
               p_hat
@@ -676,18 +640,14 @@ desctools_binomci <- function(x,
       ci_lwr <- 0
       ci_upr <- 1
       if (x != 0) {
-        ci_lwr <- stats::qbeta((1 - conf.level) / 2, x, n -
-          x + 1)
-        while (acceptbin(x, n, ci_lwr + tol) < (1 -
-          conf.level)) {
+        ci_lwr <- stats::qbeta((1 - conf.level) / 2, x, n - x + 1)
+        while (acceptbin(x, n, ci_lwr + tol) < (1 - conf.level)) {
           ci_lwr <- ci_lwr + tol
         }
       }
       if (x != n) {
-        ci_upr <- stats::qbeta(1 - (1 - conf.level) / 2, x +
-          1, n - x)
-        while (acceptbin(x, n, ci_upr - tol) < (1 -
-          conf.level)) {
+        ci_upr <- stats::qbeta(1 - (1 - conf.level) / 2, x + 1, n - x)
+        while (acceptbin(x, n, ci_upr - tol) < (1 - conf.level)) {
           ci_upr <- ci_upr - tol
         }
       }
