@@ -4,27 +4,30 @@
 #'
 #' Estimate the proportion of responders within a studied population.
 #'
+#' @inheritParams prop_strat_wilson
 #' @inheritParams argument_convention
+#' @param .stats (`character`)\cr statistics to select for the table. Run `get_stats("estimate_proportion")`
+#'   to see available statistics for this function.
+#' @param method (`string`)\cr the method used to construct the confidence interval
+#'   for proportion of successful outcomes; one of `waldcc`, `wald`, `clopper-pearson`,
+#'   `wilson`, `wilsonc`, `strat_wilson`, `strat_wilsonc`, `agresti-coull` or `jeffreys`.
+#' @param long (`flag`)\cr a long description is required.
 #'
 #' @seealso [h_proportions]
 #'
 #' @name estimate_proportions
+#' @order 1
 NULL
 
 #' @describeIn estimate_proportions Statistics function estimating a
 #'   proportion along with its confidence interval.
 #'
-#' @inheritParams prop_strat_wilson
 #' @param df (`logical` or `data.frame`)\cr if only a logical vector is used,
 #'   it indicates whether each subject is a responder or not. `TRUE` represents
 #'   a successful outcome. If a `data.frame` is provided, also the `strata` variable
 #'   names must be provided in `variables` as a list element with the strata strings.
 #'   In the case of `data.frame`, the logical vector of responses must be indicated as a
 #'   variable name in `.var`.
-#' @param method (`string`)\cr the method used to construct the confidence interval
-#'   for proportion of successful outcomes; one of `waldcc`, `wald`, `clopper-pearson`,
-#'   `wilson`, `wilsonc`, `strat_wilson`, `strat_wilsonc`, `agresti-coull` or `jeffreys`.
-#' @param long (`flag`)\cr a long description is required.
 #'
 #' @return
 #' * `s_proportion()` returns statistics `n_prop` (`n` and proportion) and `prop_ci` (proportion CI) for a
@@ -140,8 +143,6 @@ a_proportion <- make_afun(
 #' @describeIn estimate_proportions Layout-creating function which can take statistics function arguments
 #'   and additional format arguments. This function is a wrapper for [rtables::analyze()].
 #'
-#' @param ... other arguments are ultimately conveyed to [s_proportion()].
-#'
 #' @return
 #' * `estimate_proportion()` returns a layout object suitable for passing to further layouting functions,
 #'   or to [rtables::build_table()]. Adding this function to an `rtable` layout will add formatted rows containing
@@ -160,8 +161,20 @@ a_proportion <- make_afun(
 #'   build_table(df = dta_test)
 #'
 #' @export
+#' @order 2
 estimate_proportion <- function(lyt,
                                 vars,
+                                conf_level = 0.95,
+                                method = c(
+                                  "waldcc", "wald", "clopper-pearson",
+                                  "wilson", "wilsonc", "strat_wilson", "strat_wilsonc",
+                                  "agresti-coull", "jeffreys"
+                                ),
+                                weights = NULL,
+                                max_iterations = 50,
+                                variables = list(strata = NULL),
+                                long = FALSE,
+                                na_str = default_na_str(),
                                 nested = TRUE,
                                 ...,
                                 show_labels = "hidden",
@@ -170,6 +183,11 @@ estimate_proportion <- function(lyt,
                                 .formats = NULL,
                                 .labels = NULL,
                                 .indent_mods = NULL) {
+  extra_args <- list(
+    conf_level = conf_level, method = method, weights = weights, max_iterations = max_iterations,
+    variables = variables, long = long, ...
+  )
+
   afun <- make_afun(
     a_proportion,
     .stats = .stats,
@@ -181,8 +199,9 @@ estimate_proportion <- function(lyt,
     lyt,
     vars,
     afun = afun,
+    na_str = na_str,
     nested = nested,
-    extra_args = list(...),
+    extra_args = extra_args,
     show_labels = show_labels,
     table_names = table_names
   )
@@ -503,6 +522,7 @@ d_proportion <- function(conf_level,
 #' ests <- strata_data["TRUE", ] / ns
 #' vars <- ests * (1 - ests) / ns
 #' weights <- rep(1 / length(ns), length(ns))
+#'
 #' strata_normal_quantile(vars, weights, 0.95)
 #'
 #' @export
