@@ -4,6 +4,7 @@
 #'
 #' Tabulate statistics such as response rate and odds ratio for population subgroups.
 #'
+#' @inheritParams extract_rsp_subgroups
 #' @inheritParams argument_convention
 #'
 #' @details These functions create a layout starting from a data frame which contains
@@ -36,56 +37,6 @@
 #' )
 #' df
 #'
-#' @name response_subgroups
-NULL
-
-#' Prepares Response Data for Population Subgroups in Data Frames
-#'
-#' @description `r lifecycle::badge("stable")`
-#'
-#' Prepares response rates and odds ratios for population subgroups in data frames. Simple wrapper
-#' for [h_odds_ratio_subgroups_df()] and [h_proportion_subgroups_df()]. Result is a list of two
-#' `data.frames`: `prop` and `or`. `variables` corresponds to the names of variables found in `data`,
-#' passed as a named `list` and requires elements `rsp`, `arm` and optionally `subgroups` and `strat`.
-#' `groups_lists` optionally specifies groupings for `subgroups` variables.
-#'
-#' @inheritParams argument_convention
-#' @inheritParams response_subgroups
-#' @param label_all (`string`)\cr label for the total population analysis.
-#'
-#' @return A named list of two elements:
-#'   * `prop`: A `data.frame` containing columns `arm`, `n`, `n_rsp`, `prop`, `subgroup`, `var`,
-#'     `var_label`, and `row_type`.
-#'   * `or`: A `data.frame` containing columns `arm`, `n_tot`, `or`, `lcl`, `ucl`, `conf_level`,
-#'     `subgroup`, `var`, `var_label`, and `row_type`.
-#'
-#' @seealso [response_subgroups]
-#'
-#' @examples
-#' library(dplyr)
-#' library(forcats)
-#'
-#' adrs <- tern_ex_adrs
-#' adrs_labels <- formatters::var_labels(adrs)
-#'
-#' adrs_f <- adrs %>%
-#'   filter(PARAMCD == "BESRSPI") %>%
-#'   filter(ARM %in% c("A: Drug X", "B: Placebo")) %>%
-#'   droplevels() %>%
-#'   mutate(
-#'     # Reorder levels of factor to make the placebo group the reference arm.
-#'     ARM = fct_relevel(ARM, "B: Placebo"),
-#'     rsp = AVALC == "CR"
-#'   )
-#' formatters::var_labels(adrs_f) <- c(adrs_labels, "Response")
-#'
-#' # Unstratified analysis.
-#' df <- extract_rsp_subgroups(
-#'   variables = list(rsp = "rsp", arm = "ARM", subgroups = c("SEX", "BMRKR2")),
-#'   data = adrs_f
-#' )
-#' df
-#'
 #' # Stratified analysis.
 #' df_strat <- extract_rsp_subgroups(
 #'   variables = list(rsp = "rsp", arm = "ARM", subgroups = c("SEX", "BMRKR2"), strat = "STRATA1"),
@@ -107,6 +58,32 @@ NULL
 #' )
 #' df_grouped
 #'
+#' @name response_subgroups
+#' @order 1
+NULL
+
+#' Prepares Response Data for Population Subgroups in Data Frames
+#'
+#' @description `r lifecycle::badge("stable")`
+#'
+#' Prepares response rates and odds ratios for population subgroups in data frames. Simple wrapper
+#' for [h_odds_ratio_subgroups_df()] and [h_proportion_subgroups_df()]. Result is a list of two
+#' `data.frames`: `prop` and `or`. `variables` corresponds to the names of variables found in `data`,
+#' passed as a named `list` and requires elements `rsp`, `arm` and optionally `subgroups` and `strat`.
+#' `groups_lists` optionally specifies groupings for `subgroups` variables.
+#'
+#' @inheritParams argument_convention
+#' @inheritParams response_subgroups
+#' @param label_all (`string`)\cr label for the total population analysis.
+#'
+#' @return A named list of two elements:
+#'   * `prop`: A `data.frame` containing columns `arm`, `n`, `n_rsp`, `prop`, `subgroup`, `var`,
+#'     `var_label`, and `row_type`.
+#'   * `or`: A `data.frame` containing columns `arm`, `n_tot`, `or`, `lcl`, `ucl`, `conf_level`,
+#'     `subgroup`, `var`, `var_label`, and `row_type`.
+#'
+#' @seealso [response_subgroups]
+#'
 #' @export
 extract_rsp_subgroups <- function(variables,
                                   data,
@@ -139,14 +116,15 @@ extract_rsp_subgroups <- function(variables,
 #'
 #' @keywords internal
 a_response_subgroups <- function(.formats = list(
-                                   n = "xx",
+                                   n = "xx", # nolint start
                                    n_rsp = "xx",
                                    prop = "xx.x%",
                                    n_tot = "xx",
                                    or = list(format_extreme_values(2L)),
                                    ci = list(format_extreme_values_ci(2L)),
-                                   pval = "x.xxxx | (<0.0001)"
-                                 )) {
+                                   pval = "x.xxxx | (<0.0001)" # nolint end
+                                 ),
+                                 na_str = default_na_str()) {
   checkmate::assert_list(.formats)
   checkmate::assert_subset(
     names(.formats),
@@ -154,19 +132,30 @@ a_response_subgroups <- function(.formats = list(
   )
 
   afun_lst <- Map(
-    function(stat, fmt) {
+    function(stat, fmt, na_str) {
       if (stat == "ci") {
         function(df, labelstr = "", ...) {
-          in_rows(.list = combine_vectors(df$lcl, df$ucl), .labels = as.character(df$subgroup), .formats = fmt)
+          in_rows(
+            .list = combine_vectors(df$lcl, df$ucl),
+            .labels = as.character(df$subgroup),
+            .formats = fmt,
+            .format_na_strs = na_str
+          )
         }
       } else {
         function(df, labelstr = "", ...) {
-          in_rows(.list = as.list(df[[stat]]), .labels = as.character(df$subgroup), .formats = fmt)
+          in_rows(
+            .list = as.list(df[[stat]]),
+            .labels = as.character(df$subgroup),
+            .formats = fmt,
+            .format_na_strs = na_str
+          )
         }
       }
     },
     stat = names(.formats),
-    fmt = .formats
+    fmt = .formats,
+    na_str = na_str
   )
 
   afun_lst
@@ -203,9 +192,13 @@ a_response_subgroups <- function(.formats = list(
 #'   )
 #'
 #' @export
+#' @order 2
 tabulate_rsp_subgroups <- function(lyt,
                                    df,
-                                   vars = c("n_tot", "n", "prop", "or", "ci")) {
+                                   vars = c("n_tot", "n", "prop", "or", "ci"),
+                                   groups_lists = list(),
+                                   label_all = "All Patients",
+                                   na_str = default_na_str()) {
   conf_level <- df$or$conf_level[1]
   method <- if ("pval_label" %in% names(df$or)) {
     df$or$pval_label[1]
@@ -213,7 +206,9 @@ tabulate_rsp_subgroups <- function(lyt,
     NULL
   }
 
-  afun_lst <- a_response_subgroups()
+  extra_args <- list(groups_lists = groups_lists, conf_level = conf_level, method = method, label_all = label_all)
+
+  afun_lst <- a_response_subgroups(na_str = na_str)
   colvars <- d_rsp_subgroups_colvars(vars, conf_level = conf_level, method = method)
 
   colvars_prop <- list(
@@ -228,23 +223,27 @@ tabulate_rsp_subgroups <- function(lyt,
   # Columns from table_prop are optional.
   if (length(colvars_prop$vars) > 0) {
     lyt_prop <- split_cols_by(lyt = lyt, var = "arm")
-    lyt_prop <- split_rows_by(
-      lyt = lyt_prop,
-      var = "row_type",
-      split_fun = keep_split_levels("content"),
-      nested = FALSE
-    )
-    lyt_prop <- summarize_row_groups(
-      lyt = lyt_prop,
-      var = "var_label",
-      cfun = afun_lst[names(colvars_prop$labels)]
-    )
     lyt_prop <- split_cols_by_multivar(
       lyt = lyt_prop,
       vars = colvars_prop$vars,
       varlabels = colvars_prop$labels
     )
 
+    # "All Patients" row
+    lyt_prop <- split_rows_by(
+      lyt = lyt_prop,
+      var = "row_type",
+      split_fun = keep_split_levels("content"),
+      nested = FALSE,
+      child_labels = "hidden"
+    )
+    lyt_prop <- analyze_colvars(
+      lyt = lyt_prop,
+      afun = afun_lst[names(colvars_prop$labels)],
+      na_str = na_str,
+      extra_args = extra_args
+    )
+
     if ("analysis" %in% df$prop$row_type) {
       lyt_prop <- split_rows_by(
         lyt = lyt_prop,
@@ -257,7 +256,9 @@ tabulate_rsp_subgroups <- function(lyt,
       lyt_prop <- analyze_colvars(
         lyt = lyt_prop,
         afun = afun_lst[names(colvars_prop$labels)],
-        inclNAs = TRUE
+        na_str = na_str,
+        inclNAs = TRUE,
+        extra_args = extra_args
       )
     }
 
@@ -268,21 +269,25 @@ tabulate_rsp_subgroups <- function(lyt,
 
   # Columns "n_tot", "or", "ci" in table_or are required.
   lyt_or <- split_cols_by(lyt = lyt, var = "arm")
-  lyt_or <- split_rows_by(
-    lyt = lyt_or,
-    var = "row_type",
-    split_fun = keep_split_levels("content"),
-    nested = FALSE
-  )
   lyt_or <- split_cols_by_multivar(
     lyt = lyt_or,
     vars = colvars_or$vars,
     varlabels = colvars_or$labels
   )
-  lyt_or <- summarize_row_groups(
+
+  # "All Patients" row
+  lyt_or <- split_rows_by(
     lyt = lyt_or,
-    var = "var_label",
-    cfun = afun_lst[names(colvars_or$labels)]
+    var = "row_type",
+    split_fun = keep_split_levels("content"),
+    nested = FALSE,
+    child_labels = "hidden"
+  )
+  lyt_or <- analyze_colvars(
+    lyt = lyt_or,
+    afun = afun_lst[names(colvars_or$labels)],
+    na_str = na_str,
+    extra_args = extra_args
   ) %>%
     append_topleft("Baseline Risk Factors")
 
@@ -298,7 +303,9 @@ tabulate_rsp_subgroups <- function(lyt,
     lyt_or <- analyze_colvars(
       lyt = lyt_or,
       afun = afun_lst[names(colvars_or$labels)],
-      inclNAs = TRUE
+      na_str = na_str,
+      inclNAs = TRUE,
+      extra_args = extra_args
     )
   }
   table_or <- build_table(lyt_or, df = df$or)
