@@ -8,8 +8,11 @@
 #' or the change from baseline values (post-baseline) are then summarized.
 #'
 #' @inheritParams argument_convention
+#' @param .stats (`character`)\cr statistics to select for the table. Run `get_stats("analyze_vars_numeric)`
+#'   to see available statistics for this function.
 #'
 #' @name summarize_change
+#' @order 1
 NULL
 
 #' @describeIn summarize_change Statistics function that summarizes baseline or post-baseline visits.
@@ -20,13 +23,6 @@ NULL
 #' @note The data in `df` must be either all be from baseline or post-baseline visits. Otherwise
 #'   an error will be thrown.
 #'
-#' @examples
-#' df <- data.frame(
-#'   chg = c(1, 2, 3),
-#'   is_bl = c(TRUE, TRUE, TRUE),
-#'   val = c(4, 5, 6)
-#' )
-#'
 #' @keywords internal
 s_change_from_baseline <- function(df,
                                    .var,
@@ -55,7 +51,6 @@ s_change_from_baseline <- function(df,
 #' @return
 #' * `a_change_from_baseline()` returns the corresponding list with formatted [rtables::CellValue()].
 #'
-#'
 #' @keywords internal
 a_change_from_baseline <- make_afun(
   s_change_from_baseline,
@@ -89,11 +84,9 @@ a_change_from_baseline <- make_afun(
 #'   either baseline or post-baseline data.
 #'
 #' @examples
-#' # `summarize_change()`
-#'
-#' ## Fabricated dataset.
 #' library(dplyr)
 #'
+#' ## Fabricate dataset
 #' dta_test <- data.frame(
 #'   USUBJID = rep(1:6, each = 3),
 #'   AVISIT = rep(paste0("V", 1:3), 6),
@@ -113,13 +106,15 @@ a_change_from_baseline <- make_afun(
 #'   split_rows_by("AVISIT") %>%
 #'   summarize_change("CHG", variables = list(value = "AVAL", baseline_flag = "ABLFLL")) %>%
 #'   build_table(dta_test)
-#' \donttest{
-#' Viewer(results)
-#' }
+#'
+#' results
 #'
 #' @export
+#' @order 2
 summarize_change <- function(lyt,
                              vars,
+                             variables,
+                             na_str = default_na_str(),
                              nested = TRUE,
                              ...,
                              table_names = vars,
@@ -127,6 +122,8 @@ summarize_change <- function(lyt,
                              .formats = NULL,
                              .labels = NULL,
                              .indent_mods = NULL) {
+  extra_args <- list(variables = variables, ...)
+
   afun <- make_afun(
     a_change_from_baseline,
     .stats = .stats,
@@ -139,8 +136,9 @@ summarize_change <- function(lyt,
     lyt,
     vars,
     afun = afun,
+    na_str = na_str,
     nested = nested,
-    extra_args = list(...),
+    extra_args = extra_args,
     table_names = table_names
   )
 }
