@@ -5,9 +5,13 @@
 #' Summarize results of a Poisson Negative Binomial Regression.
 #' This can be used to analyze count and/or frequency data using a linear model.
 #'
+#' @inheritParams h_glm_count
 #' @inheritParams argument_convention
+#' @param .stats (`character`)\cr statistics to select for the table. Run `get_stats("summarize_glm_count")`
+#'   to see available statistics for this function.
 #'
 #' @name summarize_glm_count
+#' @order 1
 NULL
 
 #' Helper Functions for Poisson Models.
@@ -88,7 +92,6 @@ h_glm_poisson <- function(.var,
 #' @return
 #' * `h_glm_quasipoisson()` returns the results of a Quasi-Poisson model.
 #'
-#'
 #' @keywords internal
 h_glm_quasipoisson <- function(.var,
                                .df_row,
@@ -147,7 +150,6 @@ h_glm_quasipoisson <- function(.var,
 #' @return
 #' * `h_glm_count()` returns the results of the selected model.
 #'
-#'
 #' @keywords internal
 h_glm_count <- function(.var,
                         .df_row,
@@ -175,7 +177,6 @@ h_glm_count <- function(.var,
 #' @return
 #' * `h_ppmeans()` returns the estimated means.
 #'
-#'
 #' @keywords internal
 h_ppmeans <- function(obj, .df_row, arm, conf_level) {
   alpha <- 1 - conf_level
@@ -216,8 +217,6 @@ h_ppmeans <- function(obj, .df_row, arm, conf_level) {
 #' @describeIn summarize_glm_count Statistics function that produces a named list of results
 #'   of the investigated Poisson model.
 #'
-#' @inheritParams h_glm_count
-#'
 #' @return
 #' * `s_glm_count()` returns a named `list` of 5 statistics:
 #'   * `n`: Count of complete sample size for the group.
@@ -227,7 +226,6 @@ h_ppmeans <- function(obj, .df_row, arm, conf_level) {
 #'   * `rate_ratio_ci`: Confidence level for the rate ratio.
 #'   * `pval`: p-value.
 #'
-#'
 #' @keywords internal
 s_glm_count <- function(df,
                         .var,
@@ -322,7 +320,6 @@ s_glm_count <- function(df,
 #' @return
 #' * `a_glm_count()` returns the corresponding list with formatted [rtables::CellValue()].
 #'
-#'
 #' @keywords internal
 a_glm_count <- make_afun(
   s_glm_count,
@@ -355,6 +352,7 @@ a_glm_count <- make_afun(
 #'
 #' @examples
 #' library(dplyr)
+#'
 #' anl <- tern_ex_adtte %>% filter(PARAMCD == "TNE")
 #' anl$AVAL_f <- as.factor(anl$AVAL)
 #'
@@ -393,12 +391,21 @@ a_glm_count <- make_afun(
 #'       rate_ratio_ci = "Rate Ratio CI", pval = "p value"
 #'     )
 #'   )
+#'
 #' build_table(lyt = lyt, df = anl)
 #'
 #' @export
+#' @order 2
 summarize_glm_count <- function(lyt,
                                 vars,
+                                variables,
+                                distribution,
+                                conf_level,
+                                rate_mean_method,
+                                weights = stats::weights,
+                                scale = 1,
                                 var_labels,
+                                na_str = default_na_str(),
                                 nested = TRUE,
                                 ...,
                                 show_labels = "visible",
@@ -407,6 +414,11 @@ summarize_glm_count <- function(lyt,
                                 .formats = NULL,
                                 .labels = NULL,
                                 .indent_mods = NULL) {
+  extra_args <- list(
+    variables = variables, distribution = distribution, conf_level = conf_level,
+    rate_mean_method = rate_mean_method, weights = weights, scale = scale, ...
+  )
+
   afun <- make_afun(
     a_glm_count,
     .stats = .stats,
@@ -422,7 +434,8 @@ summarize_glm_count <- function(lyt,
     show_labels = show_labels,
     table_names = table_names,
     afun = afun,
+    na_str = na_str,
     nested = nested,
-    extra_args = list(...)
+    extra_args = extra_args
   )
 }
