@@ -6,6 +6,19 @@
 #'
 #' @inheritParams argument_convention
 #' @inheritParams survival_coxph_pairwise
+#' @param df (`list`)\cr of data frames containing all analysis variables. List should be
+#'   created using [extract_survival_subgroups()].
+#' @param vars (`character`)\cr the name of statistics to be reported among:
+#'   * `n_tot_events`: Total number of events per group.
+#'   * `n_events`: Number of events per group.
+#'   * `n_tot`: Total number of observations per group.
+#'   * `n`: Number of observations per group.
+#'   * `median`: Median survival time.
+#'   * `hr`: Hazard ratio.
+#'   * `ci`: Confidence interval of hazard ratio.
+#'   * `pval`: p-value of the effect.
+#'   Note, one of the statistics `n_tot` and `n_tot_events`, as well as both `hr` and `ci`
+#'   are required.
 #' @param time_unit (`string`)\cr label with unit of median survival time. Default `NULL` skips displaying unit.
 #'
 #' @details These functions create a layout starting from a data frame which contains
@@ -53,69 +66,6 @@
 #' )
 #' df
 #'
-#' @name survival_duration_subgroups
-NULL
-
-#' Prepares Survival Data for Population Subgroups in Data Frames
-#'
-#' @description `r lifecycle::badge("stable")`
-#'
-#' Prepares estimates of median survival times and treatment hazard ratios for population subgroups in
-#' data frames. Simple wrapper for [h_survtime_subgroups_df()] and [h_coxph_subgroups_df()]. Result is a `list`
-#' of two `data.frame`s: `survtime` and `hr`. `variables` corresponds to the names of variables found in `data`,
-#' passed as a named `list` and requires elements `tte`, `is_event`, `arm` and optionally `subgroups` and `strat`.
-#' `groups_lists` optionally specifies groupings for `subgroups` variables.
-#'
-#' @inheritParams argument_convention
-#' @inheritParams survival_duration_subgroups
-#' @inheritParams survival_coxph_pairwise
-#'
-#' @return A named `list` of two elements:
-#'   * `survtime`: A `data.frame` containing columns `arm`, `n`, `n_events`, `median`, `subgroup`, `var`,
-#'     `var_label`, and `row_type`.
-#'   * `hr`: A `data.frame` containing columns `arm`, `n_tot`, `n_tot_events`, `hr`, `lcl`, `ucl`, `conf_level`,
-#'     `pval`, `pval_label`, `subgroup`, `var`, `var_label`, and `row_type`.
-#'
-#' @seealso [survival_duration_subgroups]
-#'
-#' @examples
-#' library(dplyr)
-#' library(forcats)
-#'
-#' adtte <- tern_ex_adtte
-#' adtte_labels <- formatters::var_labels(adtte)
-#'
-#' adtte_f <- adtte %>%
-#'   filter(
-#'     PARAMCD == "OS",
-#'     ARM %in% c("B: Placebo", "A: Drug X"),
-#'     SEX %in% c("M", "F")
-#'   ) %>%
-#'   mutate(
-#'     # Reorder levels of ARM to display reference arm before treatment arm.
-#'     ARM = droplevels(fct_relevel(ARM, "B: Placebo")),
-#'     SEX = droplevels(SEX),
-#'     AVALU = as.character(AVALU),
-#'     is_event = CNSR == 0
-#'   )
-#' labels <- c(
-#'   "ARM" = adtte_labels[["ARM"]],
-#'   "SEX" = adtte_labels[["SEX"]],
-#'   "AVALU" = adtte_labels[["AVALU"]],
-#'   "is_event" = "Event Flag"
-#' )
-#' formatters::var_labels(adtte_f)[names(labels)] <- labels
-#'
-#' df <- extract_survival_subgroups(
-#'   variables = list(
-#'     tte = "AVAL",
-#'     is_event = "is_event",
-#'     arm = "ARM", subgroups = c("SEX", "BMRKR2")
-#'   ),
-#'   data = adtte_f
-#' )
-#' df
-#'
 #' df_grouped <- extract_survival_subgroups(
 #'   variables = list(
 #'     tte = "AVAL",
@@ -133,6 +83,32 @@ NULL
 #' )
 #' df_grouped
 #'
+#' @name survival_duration_subgroups
+#' @order 1
+NULL
+
+#' Prepares Survival Data for Population Subgroups in Data Frames
+#'
+#' @description `r lifecycle::badge("stable")`
+#'
+#' Prepares estimates of median survival times and treatment hazard ratios for population subgroups in
+#' data frames. Simple wrapper for [h_survtime_subgroups_df()] and [h_coxph_subgroups_df()]. Result is a `list`
+#' of two `data.frame`s: `survtime` and `hr`. `variables` corresponds to the names of variables found in `data`,
+#' passed as a named `list` and requires elements `tte`, `is_event`, `arm` and optionally `subgroups` and `strat`.
+#' `groups_lists` optionally specifies groupings for `subgroups` variables.
+#'
+#' @inheritParams argument_convention
+#' @inheritParams survival_duration_subgroups
+#' @inheritParams survival_coxph_pairwise
+#'
+#' @return A named `list` of two elements:
+#'   * `survtime`: A `data.frame` containing columns `arm`, `n`, `n_events`, `median`, `subgroup`, `var`,
+#'     `var_label`, and `row_type`.
+#'   * `hr`: A `data.frame` containing columns `arm`, `n_tot`, `n_tot_events`, `hr`, `lcl`, `ucl`, `conf_level`,
+#'     `pval`, `pval_label`, `subgroup`, `var`, `var_label`, and `row_type`.
+#'
+#' @seealso [survival_duration_subgroups]
+#'
 #' @export
 extract_survival_subgroups <- function(variables,
                                        data,
@@ -163,7 +139,7 @@ extract_survival_subgroups <- function(variables,
 #' * `a_survival_subgroups()` returns the corresponding list with formatted [rtables::CellValue()].
 #'
 #' @keywords internal
-a_survival_subgroups <- function(.formats = list(
+a_survival_subgroups <- function(.formats = list( # nolint start
                                    n = "xx",
                                    n_events = "xx",
                                    n_tot_events = "xx",
@@ -172,7 +148,8 @@ a_survival_subgroups <- function(.formats = list(
                                    hr = list(format_extreme_values(2L)),
                                    ci = list(format_extreme_values_ci(2L)),
                                    pval = "x.xxxx | (<0.0001)"
-                                 )) {
+                                 ),
+                                 na_str = default_na_str()) { # nolint end
   checkmate::assert_list(.formats)
   checkmate::assert_subset(
     names(.formats),
@@ -180,13 +157,14 @@ a_survival_subgroups <- function(.formats = list(
   )
 
   afun_lst <- Map(
-    function(stat, fmt) {
+    function(stat, fmt, na_str) {
       if (stat == "ci") {
         function(df, labelstr = "", ...) {
           in_rows(
             .list = combine_vectors(df$lcl, df$ucl),
             .labels = as.character(df$subgroup),
-            .formats = fmt
+            .formats = fmt,
+            .format_na_strs = na_str
           )
         }
       } else {
@@ -194,13 +172,15 @@ a_survival_subgroups <- function(.formats = list(
           in_rows(
             .list = as.list(df[[stat]]),
             .labels = as.character(df$subgroup),
-            .formats = fmt
+            .formats = fmt,
+            .format_na_strs = na_str
           )
         }
       }
     },
     stat = names(.formats),
-    fmt = .formats
+    fmt = .formats,
+    na_str = na_str
   )
 
   afun_lst
@@ -210,20 +190,6 @@ a_survival_subgroups <- function(.formats = list(
 #'   summarizing survival by subgroup. This function is a wrapper for [rtables::analyze_colvars()]
 #'   and [rtables::summarize_row_groups()].
 #'
-#' @param df (`list`)\cr of data frames containing all analysis variables. List should be
-#'   created using [extract_survival_subgroups()].
-#' @param vars (`character`)\cr the name of statistics to be reported among:
-#'   * `n_tot_events`: Total number of events per group.
-#'   * `n_events`: Number of events per group.
-#'   * `n_tot`: Total number of observations per group.
-#'   * `n`: Number of observations per group.
-#'   * `median`: Median survival time.
-#'   * `hr`: Hazard ratio.
-#'   * `ci`: Confidence interval of hazard ratio.
-#'   * `pval`: p-value of the effect.
-#'   Note, one of the statistics `n_tot` and `n_tot_events`, as well as both `hr` and `ci`
-#'   are required.
-#'
 #' @return An `rtables` table summarizing survival by subgroup.
 #'
 #' @examples
@@ -240,14 +206,20 @@ a_survival_subgroups <- function(.formats = list(
 #'   )
 #'
 #' @export
+#' @order 2
 tabulate_survival_subgroups <- function(lyt,
                                         df,
                                         vars = c("n_tot_events", "n_events", "median", "hr", "ci"),
-                                        time_unit = NULL) {
+                                        groups_lists = list(),
+                                        label_all = "All Patients",
+                                        time_unit = NULL,
+                                        na_str = default_na_str()) {
   conf_level <- df$hr$conf_level[1]
   method <- df$hr$pval_label[1]
 
-  afun_lst <- a_survival_subgroups()
+  extra_args <- list(groups_lists = groups_lists, conf_level = conf_level, method = method, label_all = label_all)
+
+  afun_lst <- a_survival_subgroups(na_str = na_str)
   colvars <- d_survival_subgroups_colvars(
     vars,
     conf_level = conf_level,
@@ -276,7 +248,9 @@ tabulate_survival_subgroups <- function(lyt,
     lyt_survtime <- summarize_row_groups(
       lyt = lyt_survtime,
       var = "var_label",
-      cfun = afun_lst[names(colvars_survtime$labels)]
+      cfun = afun_lst[names(colvars_survtime$labels)],
+      na_str = na_str,
+      extra_args = extra_args
     )
     lyt_survtime <- split_cols_by_multivar(
       lyt = lyt_survtime,
@@ -296,7 +270,9 @@ tabulate_survival_subgroups <- function(lyt,
       lyt_survtime <- analyze_colvars(
         lyt = lyt_survtime,
         afun = afun_lst[names(colvars_survtime$labels)],
-        inclNAs = TRUE
+        na_str = na_str,
+        inclNAs = TRUE,
+        extra_args = extra_args
       )
     }
 
@@ -316,7 +292,9 @@ tabulate_survival_subgroups <- function(lyt,
   lyt_hr <- summarize_row_groups(
     lyt = lyt_hr,
     var = "var_label",
-    cfun = afun_lst[names(colvars_hr$labels)]
+    cfun = afun_lst[names(colvars_hr$labels)],
+    na_str = na_str,
+    extra_args = extra_args
   )
   lyt_hr <- split_cols_by_multivar(
     lyt = lyt_hr,
@@ -337,7 +315,9 @@ tabulate_survival_subgroups <- function(lyt,
     lyt_hr <- analyze_colvars(
       lyt = lyt_hr,
       afun = afun_lst[names(colvars_hr$labels)],
-      inclNAs = TRUE
+      na_str = na_str,
+      inclNAs = TRUE,
+      extra_args = extra_args
     )
   }
   table_hr <- build_table(lyt_hr, df = df$hr)
