@@ -18,12 +18,8 @@ testthat::test_that("g_forest default plot works", {
   tbl <- basic_table() %>%
     tabulate_rsp_subgroups(df)
 
-  result <- testthat::expect_silent(
-    g_forest(
-      tbl,
-      draw = FALSE
-    )
-  )
+  g_forest <- g_forest(tbl)
+  vdiffr::expect_doppelganger(title = "g_forest", fig = g_forest)
 })
 
 testthat::test_that("g_forest works with custom arguments", {
@@ -36,7 +32,7 @@ testthat::test_that("g_forest works with custom arguments", {
     rrow("row 2", 1.2, c(1.1, 1.4))
   )
 
-  result <- testthat::expect_silent(
+  g_forest_custom <-
     g_forest(
       tbl = tbl,
       col_x = 1,
@@ -44,8 +40,8 @@ testthat::test_that("g_forest works with custom arguments", {
       xlim = c(0.5, 2),
       x_at = c(0.5, 1, 2),
       vline = 1,
-      forest_header = c("Hello", "World"),
-      draw = FALSE
+      forest_header = c("Hello", "World")
     )
-  )
+
+  vdiffr::expect_doppelganger(title = "g_forest_custom", fig = g_forest_custom)
 })
